@@ -868,7 +868,7 @@ def mk_flat(cls, method, *, func_name='flat_func'):
     sig_flat = sig_cls + sig_method
     sig_flat = sig_flat.remove_names(['self'])
     sig_flat = sig_flat.replace(return_annotation=sig_method.return_annotation)
-    print(f'sig_flat: {sig_flat}')
+
     def flat_func(**kwargs):
         if (
             len(
@@ -1004,6 +1004,10 @@ def handle_raw_req(func):
     return input_mapper
 
 
+def base_output_mapper(output, input_kwargs):
+    return output
+
+
 # TODO: Definitely want to move this to a place that is specialized for defining serialization needs
 #   First, it's not really a decorator.
 #   Secondly, the user should be able to easily define the serialization logic for their needs
@@ -1068,21 +1072,44 @@ def send_json_resp(func):
             mapped_output = func(output, input_kwargs)
             return dumps(mapped_output, cls=JsonRespEncoder)
 
-    output_mapper.content_type = 'json'
+    output_mapper.content_type = 'application/json'
     return output_mapper
 
 
 def send_html_resp(func):
-    async def output_mapper(output, input_kwargs):
-        mapped_output = func(output, input_kwargs)
-        if isawaitable(mapped_output):
-            mapped_output = await mapped_output
-        return web.Response(text=mapped_output, content_type='text/html')
+    # TODO bottle support
+    # async def output_mapper(output, input_kwargs):
+    #     mapped_output = func(output, input_kwargs)
+    #     if isawaitable(mapped_output):
+    #         mapped_output = await mapped_output
+    #     return Response(text=mapped_output, content_type='text/html')
 
-    output_mapper.content_type = 'html'
+    func.content_type = 'text/html'
+    return func
+
+
+def send_binary_resp(func):
+    # TODO async support
+    BINARY_CONTENT_TYPE = 'application/octet-stream'
+
+    def output_mapper(output, input_kwargs):
+        from bottle import response
+
+        mapped_output = func(output, input_kwargs)
+        response.content_type = BINARY_CONTENT_TYPE
+        return mapped_output
+
+    output_mapper.content_type = BINARY_CONTENT_TYPE
+    output_mapper.response_schema = {'type': 'binary'}
     return output_mapper
 
 
+def binary_output(func):
+    output_mapper = send_binary_resp(base_output_mapper)
+    func.output_mapper = output_mapper
+    return func
+
+
 # TODO: stub
 def mk_input_mapper(input_map):
     def decorator(func):
